<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>FastMenu</name>
    <message>
        <source>Form</source>
        <translation type="vanished">Formulário</translation>
    </message>
    <message>
        <location filename="../../../fastmenu.ui" line="20"/>
        <source>Fast options</source>
        <translation>Opções rápidas</translation>
    </message>
    <message>
        <location filename="../../../fastmenu.ui" line="40"/>
        <source> ❶ ❷ Extended view</source>
        <translation> ❶ ❷ Vista expandida</translation>
    </message>
    <message>
        <location filename="../../../fastmenu.ui" line="45"/>
        <source> ❶ ❶ Unified view</source>
        <translation> ❶ ❶ Vista unificada</translation>
    </message>
    <message>
        <location filename="../../../fastmenu.ui" line="50"/>
        <source> ❶     Only first</source>
        <translation> ❶     Apenas o primeiro</translation>
    </message>
    <message>
        <location filename="../../../fastmenu.ui" line="55"/>
        <source>     ❷ Only second</source>
        <translation>     ❷ Apenas o segundo</translation>
    </message>
</context>
<context>
    <name>ManageSavedSettings</name>
    <message>
        <location filename="../../../managesavedsettings.ui" line="14"/>
        <source>Monitor Settings</source>
        <translation>Definições do monitor</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.ui" line="27"/>
        <source>Saved settings</source>
        <translation>Definições guardadas</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.ui" line="38"/>
        <source>Rename</source>
        <translation>Renomear</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.ui" line="45"/>
        <source>Delete</source>
        <translation>Apagar</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.ui" line="52"/>
        <source>Apply</source>
        <translation>Aplicar</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="64"/>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="67"/>
        <source>Left</source>
        <translation>Esquerda</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="70"/>
        <source>Inverted</source>
        <translation>Invertido</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="73"/>
        <source>Right</source>
        <translation>Direita</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="77"/>
        <location filename="../../../managesavedsettings.cpp" line="78"/>
        <source>True</source>
        <translation>Verdadeiro</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="77"/>
        <location filename="../../../managesavedsettings.cpp" line="78"/>
        <source>False</source>
        <translation>Falso</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="140"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="140"/>
        <source>Name:</source>
        <translation>Nome:</translation>
    </message>
</context>
<context>
    <name>MonitorInfo</name>
    <message>
        <source>Laptop LCD Monitor</source>
        <translation type="vanished">Monitor LCD de portátil</translation>
    </message>
    <message>
        <source>External VGA Monitor</source>
        <translation type="vanished">Monitor externo VGA</translation>
    </message>
    <message>
        <source>VGA Monitor</source>
        <translation type="vanished">Monitor VGA</translation>
    </message>
    <message>
        <source>External DVI Monitor</source>
        <translation type="vanished">Monitor externo DVI</translation>
    </message>
    <message>
        <source>DVI Monitor</source>
        <translation type="vanished">Monitor DVI</translation>
    </message>
    <message>
        <source>TV</source>
        <translation type="vanished">TV</translation>
    </message>
    <message>
        <source>Default Monitor</source>
        <translation type="vanished">Monitor padrão</translation>
    </message>
</context>
<context>
    <name>MonitorPictureDialog</name>
    <message>
        <source>Dialog</source>
        <translation type="vanished">Caixa de diálogo</translation>
    </message>
    <message>
        <location filename="../../../monitorpicture.ui" line="27"/>
        <source>Keep monitors attached</source>
        <translation>Manter monitores ligados</translation>
    </message>
    <message>
        <source>Magnetic attraction</source>
        <translation type="vanished">Atração magnética</translation>
    </message>
</context>
<context>
    <name>MonitorSettingsDialog</name>
    <message>
        <source>Laptop LCD Monitor</source>
        <translation type="vanished">Monitor LCD de portátil</translation>
    </message>
    <message>
        <source>External VGA Monitor</source>
        <translation type="vanished">Monitor externo VGA</translation>
    </message>
    <message>
        <source>VGA Monitor</source>
        <translation type="vanished">Monitor VGA</translation>
    </message>
    <message>
        <source>External DVI Monitor</source>
        <translation type="vanished">Monitor externo DVI</translation>
    </message>
    <message>
        <source>DVI Monitor</source>
        <translation type="vanished">Monitor DVI</translation>
    </message>
    <message>
        <source>TV</source>
        <translation type="vanished">TV</translation>
    </message>
    <message>
        <source>Default Monitor</source>
        <translation type="vanished">Monitor padrão</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation type="vanished">Automático</translation>
    </message>
    <message>
        <source>OK?</source>
        <translation type="vanished">Aceitar?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="vanished">Sim</translation>
    </message>
    <message>
        <source>About</source>
        <translation type="vanished">Sobre</translation>
    </message>
    <message>
        <source>Left of</source>
        <translation type="vanished">Esquerda de</translation>
    </message>
    <message>
        <source>Right of</source>
        <translation type="vanished">Direita de</translation>
    </message>
    <message>
        <source>Above of</source>
        <translation type="vanished">Acima de</translation>
    </message>
    <message>
        <source>Below of</source>
        <translation type="vanished">Abaixo de</translation>
    </message>
    <message>
        <source>Show the same screen on both</source>
        <translation type="vanished">Mostrar o mesmo ecrã em ambos</translation>
    </message>
    <message>
        <source>Turn off first monitor and use second monitor only</source>
        <translation type="vanished">Desligar o primeiro monitor e utilizar o segundo</translation>
    </message>
    <message>
        <source>Turn off second monitor and use first monitor only</source>
        <translation type="vanished">Desligar o segundo monitor e utilizar o primeiro</translation>
    </message>
    <message>
        <source>LXQt-config-monitor

Monitor configuration tool for LXQt.</source>
        <translation type="vanished">LXQt-config-monitor

Ferramenta de configuração de monitores do LXQt.</translation>
    </message>
    <message>
        <location filename="../../../monitorsettingsdialog.ui" line="14"/>
        <source>Monitor Settings</source>
        <translation>Definições do monitor</translation>
    </message>
    <message>
        <source>Quick Options</source>
        <translation type="vanished">Opções rápidas</translation>
    </message>
    <message>
        <source>Show the same screen on both laptop LCD and external monitor</source>
        <translation type="vanished">Mostrar o mesmo ecrã no portátil e no monitor externo</translation>
    </message>
    <message>
        <source>Extended view</source>
        <translation type="vanished">Vista detalhada</translation>
    </message>
    <message>
        <source>Turn off laptop LCD and use external monitor only</source>
        <translation type="vanished">Desligar ecrã do portátil e utilizar o monitor externo</translation>
    </message>
    <message>
        <source>Turn off external monitor and use laptop LCD only</source>
        <translation type="vanished">Desligar o monitor externo e utilizar o ecrã do portátil</translation>
    </message>
    <message>
        <location filename="../../../monitorsettingsdialog.ui" line="71"/>
        <source>Settings</source>
        <translation>Definições</translation>
    </message>
    <message>
        <source>Unify all monitors</source>
        <translation type="vanished">Unificar todos os monitores</translation>
    </message>
    <message>
        <source>Monitor Position</source>
        <translation type="vanished">Posição do monitor</translation>
    </message>
    <message>
        <source>Primary monitor:</source>
        <translation type="vanished">Monitor principal:</translation>
    </message>
    <message>
        <source>Do you want to save changes?</source>
        <translation type="vanished">Quer guardar as alterações?</translation>
    </message>
    <message>
        <source>Please, check your config before to save.</source>
        <translation type="vanished">Verifique a configuração antes de guardar.</translation>
    </message>
    <message>
        <location filename="../../../monitorsettingsdialog.cpp" line="111"/>
        <source>Fast Menu</source>
        <translation>Menu rápido</translation>
    </message>
    <message>
        <location filename="../../../monitorsettingsdialog.cpp" line="115"/>
        <source>Set position</source>
        <translation>Definir posição</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="vanished">Erro</translation>
    </message>
    <message>
        <source>Config can not be saved</source>
        <translation type="vanished">Não é possível guardar a configuração</translation>
    </message>
    <message>
        <location filename="../../../monitorsettingsdialog.cpp" line="244"/>
        <source>Advanced settings</source>
        <translation>Definições avançadas</translation>
    </message>
</context>
<context>
    <name>MonitorWidget</name>
    <message>
        <source>Turn on</source>
        <translation type="vanished">Ligar</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="21"/>
        <source>Setup</source>
        <translation>Configuração</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="29"/>
        <source> (x)</source>
        <translation> (x)</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="45"/>
        <source> (y)</source>
        <translation> (y)</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="78"/>
        <source>Resolution:</source>
        <translation>Resolução:</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="90"/>
        <source>Enable this display</source>
        <translation>Ativar este ecrã</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="98"/>
        <source>This is my primary display</source>
        <translation>Este é o ecrã principal</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="103"/>
        <source>This screen extends another display</source>
        <translation>Expandir este ecrã até outro</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="125"/>
        <source>Advanced</source>
        <translation>Avançado</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="146"/>
        <source>Refresh rate:</source>
        <translation>Taxa de atualização:</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="153"/>
        <source>Rotation:</source>
        <translation>Rotação:</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="176"/>
        <source>Info</source>
        <translation>Informação</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="182"/>
        <source>Display information</source>
        <translation>Informação do ecrã</translation>
    </message>
    <message>
        <source>Rate:</source>
        <translation type="vanished">Taxa:</translation>
    </message>
    <message>
        <source>Hz</source>
        <translation type="vanished">Hz</translation>
    </message>
    <message>
        <source>Position:</source>
        <translation type="vanished">Posição:</translation>
    </message>
    <message>
        <source>x:</source>
        <translation type="vanished">x:</translation>
    </message>
    <message>
        <source>y:</source>
        <translation type="vanished">y:</translation>
    </message>
    <message>
        <source>Brightness:</source>
        <translation type="vanished">Brilho:</translation>
    </message>
    <message>
        <source>Gamma:</source>
        <translation type="vanished">Gama:</translation>
    </message>
    <message>
        <source>:</source>
        <translation type="vanished">:</translation>
    </message>
    <message>
        <source>Backlight:</source>
        <translation type="vanished">Luz de fundo:</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation type="vanished">Automático</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="135"/>
        <source>Name: %1
</source>
        <translation>Nome: %1
</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="136"/>
        <source>Vendor: %1
</source>
        <translation>Fornecedor: %1
</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="137"/>
        <source>Serial: %1
</source>
        <translation>Série: %1
</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="138"/>
        <source>Display size: %1cm x %2cm
</source>
        <translation>Tamanho do ecrã: %1cm x %2cm
</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="139"/>
        <source>Serial number: %1
</source>
        <translation>Número de série: %1
</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="140"/>
        <source>EISA device ID: %1
</source>
        <translation>EISA do dispositivo: %1
</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="161"/>
        <source>None</source>
        <translation>Nenhuma</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="162"/>
        <source>Left</source>
        <translation>Esquerda</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="163"/>
        <source>Right</source>
        <translation>Direita</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="164"/>
        <source>Inverted</source>
        <translation>Invertido</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="255"/>
        <source>%1 Hz</source>
        <translation>%1 HZ</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Auto</source>
        <translation type="vanished">Automático</translation>
    </message>
    <message>
        <source>Monitor Settings</source>
        <translation type="obsolete">Definições do monitor</translation>
    </message>
    <message>
        <source>Quick Options</source>
        <translation type="obsolete">Opções rápidas</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="obsolete">Definições</translation>
    </message>
    <message>
        <location filename="../../../settingsdialog.cpp" line="33"/>
        <source>Manage Saved Settings</source>
        <translation>Gerir definições guardadas</translation>
    </message>
</context>
<context>
    <name>QuickOptions</name>
    <message>
        <source>Monitor Settings</source>
        <translation type="obsolete">Definições do monitor</translation>
    </message>
    <message>
        <source>Show the same screen on both laptop LCD and external monitor</source>
        <translation type="obsolete">Mostrar o mesmo ecrã no portátil e no monitor externo</translation>
    </message>
    <message>
        <source>Extended view</source>
        <translation type="obsolete">Vista detalhada</translation>
    </message>
    <message>
        <source>Turn off laptop LCD and use external monitor only</source>
        <translation type="obsolete">Desligar ecrã do portátil e utilizar o monitor externo</translation>
    </message>
    <message>
        <source>Turn off external monitor and use laptop LCD only</source>
        <translation type="obsolete">Desligar o monitor externo e utilizar o ecrã do portátil</translation>
    </message>
</context>
<context>
    <name>SaveSettings</name>
    <message>
        <source>Monitor Settings</source>
        <translation type="obsolete">Definições do monitor</translation>
    </message>
</context>
<context>
    <name>TimeoutDialog</name>
    <message>
        <location filename="../../../timeoutdialog.ui" line="14"/>
        <source>Settings are changed</source>
        <translation>Definições alteradas</translation>
    </message>
    <message>
        <location filename="../../../timeoutdialog.ui" line="46"/>
        <source>Are the current settings OK for you?</source>
        <translation>As definições estão certas para si?</translation>
    </message>
    <message>
        <source>%1 second(s) remaining</source>
        <translation type="vanished">%1 segundo(s) em falta</translation>
    </message>
    <message numerus="yes">
        <location filename="../../../timeoutdialog.cpp" line="62"/>
        <source>%n second(s) remaining</source>
        <translation>
            <numerusform>Resta %n segundo</numerusform>
            <numerusform>Restam %n segundos</numerusform>
        </translation>
    </message>
</context>
</TS>
